@@ -1,4 +1,4 @@
-__version__ = '0.1.8'
+__version__ = '0.1.9'
 
 ## Import packages
 import numpy as np
@@ -55,19 +55,7 @@ def circ_diff(a,b,r=360):
         elif diff[k] > r//2:
             diff[k] = b[k] - a[k] - r
     return diff
-def find_vm_sd(channel_responses,stim_max=180,plotting=False):
-    # fits to von Mises distribution
-    f = sp.interpolate.interp1d(np.arange(len(channel_responses)),channel_responses)
-    yReal = f(np.arange(0,len(channel_responses)-1,(len(channel_responses)-1)/stim_max))
-    yReal = np.roll(yReal,stim_max-np.argmax(yReal))
     
-    losses = [np.abs(np.sum(yReal - make_gaussian_iter(stim_max//2,sd,stim_max))) for sd in np.arange(10,180)]
-
-    if plotting:
-        plt.plot(yReal)
-        plt.plot(make_gaussian_iter(stim_max//2,np.arange(10,180)[np.argmin(losses)],stim_max))
-        
-    return np.arange(10,180)[np.argmin(losses)]
 def rotate(l,dist):
     # this is identical but faster than np.roll() for larger matrices 
     l=l.tolist()
@@ -144,10 +132,9 @@ def IEM(trialbyvoxel,features,stim_max=180,is_circular=True,nfolds=10,
     if trialbyvoxel.shape[0]!=ntrials:
         raise Exception('number of trials is not consistent between trialbyvoxel and features!')
 
-    # prep basis set, sd = cosine raised to nchannel-1
+    # prep basis set
     if channel_sd==None:
-        sd = find_vm_sd(np.cos(np.deg2rad(np.arange(180)))**(nchannels-(nchannels%2)))
-        sd = sd * stim_max/360
+        sd = 42 * stim_max//360 #(sd = approximately cosine raised to nchannel-1)
     else:
         sd = channel_sd
     if np.all(channel_mus==None):
